@@ -21,6 +21,7 @@ from .._shared import OrgUnitRef
 from .._shared import PersonRef
 from .._shared import Responsibility
 from .._shared import Validity
+from ._shared import Details
 
 # --------------------------------------------------------------------------------------
 # Manager implementations
@@ -75,6 +76,10 @@ class ManagerWrite(ManagerBase):
     )
 
 
+class ManagerDetail(ManagerWrite, Details):
+    pass
+
+
 class Manager(MOBase):
     """A MO manager object."""
 
